==> fap_0.8.8.orig.tar.bz2: fap-0.8.8/src/audio/input/metaData.cpp <==
/*
 *  Copyright (C) 2010 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include "metaData.h"

#define tr(X) X

const char* metaDataImpl::mprisTags[LAST_ID]={
tr("location"),
tr("title"),
tr("artist"),
tr("album"),
tr("track"), //tracknumber
tr("time"),
tr("mtime"),
tr("genre"),
tr("comment"),
tr("rating"),
tr("year"),
tr("arturl")};

void metaDataImpl::addInfo(const char* type, const char* info) {

	FXTRACE((10, "adding type: %s value: %s\n", type, info));

	if (info && info[0])
		_infos.replace(type, info);
}

void metaDataImpl::addInfo(const char* type, unsigned int info) {

#if FOX_MINOR>6
	addInfo(type, FXString::value(info).text());
#else
	addInfo(type, FXStringVal(info).text());
#endif
}

void metaDataImpl::addInfo(const mpris_t type, const char* info) {

	if (info && info[0]) {
		addInfo(mprisTags[type], info);
	}
}

void metaDataImpl::addInfo(const mpris_t type, unsigned int info) {

#if FOX_MINOR>6
	addInfo(type, FXString::value(info).text());
#else
	addInfo(type, FXStringVal(info).text());
#endif
}

const int metaDataImpl::moreInfo(const int i) const {

	const int j=(i<0)?_infos.first():_infos.next(i);
	return (j<_infos.size())?j:-1;
}

==> fap-0.9.0.tar.bz2: fap-0.9.0/src/audio/input/metaData.cpp <==
/*
 *  Copyright (C) 2010 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include "metaData.h"

#define tr(X) X

const char* metaDataImpl::mprisTags[LAST_ID]={
tr("location"),
tr("title"),
tr("artist"),
tr("album"),
tr("track"), //tracknumber
tr("time"),
tr("mtime"),
tr("genre"),
tr("comment"),
tr("rating"),
tr("year"),
tr("arturl")};

void metaDataImpl::addInfo(const char* type, const char* info) {

	FXTRACE((10, "adding type: %s value: %s\n", type, info));

	if (info && info[0])
		_infos.replace(type, info);
}

void metaDataImpl::addInfo(const char* type, unsigned int info) {

#if FOX_MINOR>6
	addInfo(type, FXString::value(info).text());
#else
	addInfo(type, FXStringVal(info).text());
#endif
}

void metaDataImpl::addInfo(const mpris_t type, const char* info) {

	if (info && info[0]) {
		addInfo(mprisTags[type], info);
	}
}

void metaDataImpl::addInfo(const mpris_t type, unsigned int info) {

#if FOX_MINOR>6
	addInfo(type, FXString::value(info).text());
#else
	addInfo(type, FXStringVal(info).text());
#endif
}

int metaDataImpl::moreInfo(const int i) const {

	const int j=(i<0)?_infos.first():_infos.next(i);
	return (j<_infos.size())?j:-1;
}
